# ruff: noqa: E501
"""
Microsoft Xandr API doesn't have any formal specifications. Code below is based on its documentation:
https://learn.microsoft.com/en-us/xandr/digital-platform-api/batch-segment-service
"""
from enum import Enum
from typing import Optional

from pydantic import BaseModel, Field


class BatchSegmentUploadJobPhase(str, Enum):
    ERROR = "error"
    STARTING = "starting"
    UPLOADING = "uploading"
    VALIDATING = "validating"
    PROCESSING = "processing"
    COMPLETED = "completed"


class BatchSegmentUploadJob(BaseModel):
    """
    | Fields                | Type    | Description                                                                                                                                                                                                                                                                                                                                                                                                     |
    |-----------------------|---------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
    | id                    | int     | The unique identifier of this object.                                                                                                                                                                                                                                                                                                                                                                           |
    | job_id                | string  | A string of alphanumeric characters that uniquely identifies the processing job associated with this file.                                                                                                                                                                                                                                                                                                      |
    | completed_time        | date    | The time at which file processing was completed.                                                                                                                                                                                                                                                                                                                                                                |
    | created_on            | date    | The creation date of this object.                                                                                                                                                                                                                                                                                                                                                                               |
    | last_modified         | date    | The most recent modification date of this object (usually via POST).                                                                                                                                                                                                                                                                                                                                            |
    | error_code            | int     | If "phase" = "error", this error code describes the type of error encountered. Note that an error code will only be shown here if there was an error with the uploading, validating, or processing of the file itself (i.e. does not include invalid format or invalid segment errors). Common errors are caused by unreadable files and exceeding defined object limits. Returns null if no errors were found. |
    | error_log_lines       | string  | A string containing newline-separated lines. Each line lists a validation error or the reason for an error while uploading your file. You can choose how many lines (200 by default) appear in this field.                                                                                                                                                                                                      |
    | member_id             | int     | Your member ID.                                                                                                                                                                                                                                                                                                                                                                                                 |
    | num_inactive_segment  | int     | The number of inactive segments in the file. Deduplicated.                                                                                                                                                                                                                                                                                                                                                      |
    | num_invalid_format    | int     | The number of uploaded lines containing formatting errors (This depends upon your particular file format configuration). Duplicate lines will also be considered to be an invalid format.                                                                                                                                                                                                                       |
    | num_invalid_segment   | int     | The number of invalid segments in the file. Deduplicated.                                                                                                                                                                                                                                                                                                                                                       |
    | num_invalid_timestamp | int     | The number of invalid timestamps in the file.                                                                                                                                                                                                                                                                                                                                                                   |
    | num_invalid_user      | int     | This is a count of unique input lines that have an invalid or nonexistent user                                                                                                                                                                                                                                                                                                                                  |
    | num_other_error       | int     | This is a placeholder value not currently in use.                                                                                                                                                                                                                                                                                                                                                               |
    | num_past_expiration   | int     | The number of expired segments in the file. Deduplicated.                                                                                                                                                                                                                                                                                                                                                       |
    | num_unauth_segment    | int     | The number of segments in the file which you are unauthorized to access. Deduplicated.                                                                                                                                                                                                                                                                                                                          |
    | num_valid             | int     | The number of valid lines in the uploaded file. Each user/segment combination is considered 1 line.                                                                                                                                                                                                                                                                                                             |
    | num_valid_user        | int     | This is a count of unique input lines that have a valid user ID.                                                                                                                                                                                                                                                                                                                                                |
    | percent_complete      | int     | The percentage of the processing that has been completed, given the current phase at the time of the request.                                                                                                                                                                                                                                                                                                   |
    | phase                 | enum    | The current processing status, one of "error", "starting", "uploading", "validating", "processing", or "completed".                                                                                                                                                                                                                                                                                             |
    | segment_log_lines     | string  | A string containing newline-separated lines. Each line lists a segment and how many users were successfully added to it. This field defaults to 200 lines.                                                                                                                                                                                                                                                      |
    | start_time            | date    | The time at which file upload began.                                                                                                                                                                                                                                                                                                                                                                            |
    | time_to_process       | decimal | How long it took to process the segment file, in minutes.                                                                                                                                                                                                                                                                                                                                                       |
    | upload_url            | string  | The URL where you'll upload your segment data file.                                                                                                                                                                                                                                                                                                                                                             |
    | uploaded_time         | date    | The time at which the file associated with this job ID was uploaded.                                                                                                                                                                                                                                                                                                                                            |
    | validated_time        | date    | The time at which file validation was completed.                                                                                                                                                                                                                                                                                                                                                                |
    """
    id: Optional[int] = Field(None, description="The unique identifier of this object.")
    job_id: Optional[str] = Field(None, description="A string of alphanumeric characters that uniquely identifies the processing job associated with this file.")
    completed_time: Optional[str] = Field(None, description="The time at which file processing was completed.")
    created_on: Optional[str] = Field(None, description="The creation date of this object.")
    last_modified: Optional[str] = Field(None, description="The most recent modification date of this object (usually via POST).")
    error_code: Optional[int] = Field(None, description="If 'phase' = 'error', this error code describes the type of error encountered. Returns null if no errors were found.")
    error_log_lines: Optional[str] = Field(None, description="A string containing newline-separated lines. Each line lists a validation error or the reason for an error while uploading your file. Defaults to 200 lines.")
    member_id: Optional[int] = Field(None, description="Your member ID.")
    num_inactive_segment: Optional[int] = Field(None, description="The number of inactive segments in the file. Deduplicated.")
    num_invalid_format: Optional[int] = Field(None, description="The number of uploaded lines containing formatting errors. Duplicate lines are also considered invalid.")
    num_invalid_segment: Optional[int] = Field(None, description="The number of invalid segments in the file. Deduplicated.")
    num_invalid_timestamp: Optional[int] = Field(None, description="The number of invalid timestamps in the file.")
    num_invalid_user: Optional[int] = Field(None, description="A count of unique input lines that have an invalid or nonexistent user.")
    num_other_error: Optional[int] = Field(None, description="A placeholder value not currently in use.")
    num_past_expiration: Optional[int] = Field(None, description="The number of expired segments in the file. Deduplicated.")
    num_unauth_segment: Optional[int] = Field(None, description="The number of segments in the file which you are unauthorized to access. Deduplicated.")
    num_valid: Optional[int] = Field(None, description="The number of valid lines in the uploaded file. Each user/segment combination is considered 1 line.")
    num_valid_user: Optional[int] = Field(None, description="A count of unique input lines that have a valid user ID.")
    percent_complete: Optional[int] = Field(None, description="The percentage of the processing that has been completed, given the current phase at the time of the request.")
    phase: Optional[BatchSegmentUploadJobPhase] = Field(None, description="The current processing status.")
    segment_log_lines: Optional[str] = Field(None, description="A string containing newline-separated lines. Each line lists a segment and how many users were successfully added to it. Defaults to 200 lines.")
    start_time: Optional[str] = Field(None, description="The time at which file upload began.")
    time_to_process: Optional[float] = Field(None, description="How long it took to process the segment file, in minutes.")
    upload_url: Optional[str] = Field(None, description="The URL where you'll upload your segment data file.")
    uploaded_time: Optional[str] = Field(None, description="The time at which the file associated with this job ID was uploaded.")
    validated_time: Optional[str] = Field(None, description="The time at which file validation was completed.")
